@@ -19,7 +19,7 @@ Finance::QuoteDB - User database tools based on Finance::Quote
 @EXPORT = ();
 @EXPORT_OK = qw /createdb updatedb addstock/ ;
 @EXPORT_TAGS = ( all => [@EXPORT_OK] );
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 =head1 SYNOPSIS
 
@@ -267,7 +267,7 @@ sub addstock {
 
 =head2 getquotes
 
-getquotes($USERsymbols, $date_start [,$date_end] )
+getquotes( $USERsymbols, $date_start [,$date_end] )
 
 This function returns quotes between $date_start and $date_end for the specified
 user symbols (comma separated list).  Range will be one day if $date_end is
@@ -276,22 +276,44 @@ omitted.
 =cut
 
 sub getquotes {
+  my ($self,$USERsymbol,$date_start,$date_end) = @_ ;
+  $date_end = $date_start if !($date_end) ;
+  my $schema = $self->schema();
+
+  my @q = $schema->resultset('Quote')
+    ->search( { symbolID=>$USERsymbol,
+                date=>{'BETWEEN',[$date_start, $date_end]} },
+              { columns=> [qw/ date day_open day_high day_low day_close volume /],
+                order_by=> [qw/ date /] });
+  @q ? return \@q : 0 ;
+}
+
+=head2 dumpquotes
+
+dumpquotes ( $USERsymbols, $date_start [,$date_end] )
+
+This function dumps quotes between $date_start and $date_end for the specified
+user symbols (comma separated list).  Range will be one day if $date_end is
+omitted.
+
+=cut
+
+sub dumpquotes {
   my ($self,$USERsymbols,$date_start,$date_end) = @_ ;
   $date_end = $date_start if !($date_end) ;
   my $schema = $self->schema();
 
   if (my @stocks = split(",",$USERsymbols)) {
     foreach my $USERsymbol (@stocks) {
-      my $rs = $schema->resultset('Quote')
-        ->search( { symbolID=>$USERsymbol,
-                    date=>{'BETWEEN',[$date_start, $date_end]} },
-                  { columns=> [qw/ date day_open day_high day_low day_close volume /],
-                    order_by=> [qw/ date /] });
-      print "STOCK : $USERsymbol\n";
-      print "DATE           OPEN     HIGH      LOW    CLOSE       VOLUME\n" ;
-      while (my $q = $rs->next()) {
-        printf "%10s %8.2f %8.2f %8.2f %8.2f %12d\n",
-          $q->date(), $q->day_open(), $q->day_high(), $q->day_low(), $q->day_close(), $q->volume() ;
+      if ( my $quotesArray = $self->getquotes ( $USERsymbol, $date_start, $date_end ) ) {
+        print "STOCK : $USERsymbol\n";
+        print "DATE           OPEN     HIGH      LOW    CLOSE       VOLUME\n" ;
+        foreach my $q (@$quotesArray) {
+          printf "%10s %8.2f %8.2f %8.2f %8.2f %12d\n",
+            $q->date(), $q->day_open(), $q->day_high(), $q->day_low(), $q->day_close(), $q->volume() ;
+        }
+      } else {
+        print "NO DATA for stock $USERsymbol\n";
       }
     }
   }
